@@ -1,9 +1,8 @@
 """ Abstract passenger factory module """
-from abc import ABC, abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.passenger.abstract_passenger import AbstractPassenger
 
-
 class PassengerCreationError(Exception):
     """ Passenger creation exception class """
     class ErrorCode(Enum):
@@ -24,14 +23,13 @@ class PassengerCreationError(Exception):
     def message(self) -> str:
         """ Passenger creation error message """
         if self.error_code == PassengerCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " passenger instance"
+            return f"Can't create {self.module} passenger instance"
         if self.error_code == PassengerCreationError.ErrorCode.parameter_missing:
             return "Parameters missing, can't create passenger instance"
         return "Passenger creation error"
 
 
-class AbstractPassengerFactory(ABC): # pylint: disable=R0903
+class AbstractPassengerFactory(Protocol): # pylint: disable=R0903
     """ Abstract passenger factory class """
-    @abstractmethod
     def create_passenger(self, p_module: str) -> AbstractPassenger:
         """ Abstract passenger factory """
