@@ -1,11 +1,10 @@
 """ Abstract queue factory module """
-from abc import abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.client.log import Log
 from databus.database.abstract_database import AbstractDatabase
 from databus.pqueue.abstract_queue import AbstractQueue
 
-
 class QueueCreationError(Exception):
     """ Queue creation exception """
 
@@ -30,15 +29,14 @@ class QueueCreationError(Exception):
     def message(self) -> str:
         """ Error message as text """
         if self.error_code == QueueCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " queue instance"
+            return f"Can't create {self.module} queue instance"
         if self.error_code == QueueCreationError.ErrorCode.parameter_missing:
             return "Parameters missing, can't create database instance"
         return "Database creation error"
 
 
-class AbstractQueueFactory: # pylint: disable=R0903
+class AbstractQueueFactory(Protocol): # pylint: disable=R0903
     """ Abstract queue factory class """
-    @abstractmethod
     def create_queue(self,
                      p_module: str,
                      p_database: AbstractDatabase,
