@@ -1,10 +1,9 @@
 """ Abstract puller factory module """
-from abc import ABC, abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.client.log import Log
 from databus.puller.abstract_puller import AbstractPuller
 
-
 class PullerCreationError(Exception):
     """ Puller creation exception class """
 
@@ -26,14 +25,13 @@ class PullerCreationError(Exception):
     def message(self) -> str:
         """ Puller creation error message """
         if self.error_code == PullerCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " puller instance"
+            return f"Can't create {self.module} puller instance"
         if self.error_code == PullerCreationError.ErrorCode.parameter_missing:
             return "Parameters missing, can't create puller instance"
         return "Puller creation error"
 
 
-class AbstractPullerFactory(ABC): # pylint: disable=R0903
+class AbstractPullerFactory(Protocol): # pylint: disable=R0903
     """ Abstract puller factory class """
-    @abstractmethod
     def create_puller(self, p_module: str, p_log: Log) -> AbstractPuller:
         """ Puller factory """
