@@ -1,10 +1,9 @@
 """ Abstract pusher factory module """
-from abc import ABC, abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.client.log import Log
 from databus.pusher.abstract_pusher import AbstractPusher
 
-
 class PusherCreationError(Exception):
     """ Pusher creation exception class """
 
@@ -26,14 +25,13 @@ class PusherCreationError(Exception):
     def message(self) -> str:
         """ Error message as text """
         if self.error_code == PusherCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " pusher instance"
+            return f"Can't create {self.module} pusher instance"
         if self.error_code == PusherCreationError.ErrorCode.parameter_missing:
             return "Parameters missing, can't create pusher instance"
         return "Pusher creation error"
 
 
-class AbstractPusherFactory(ABC): # pylint: disable=R0903
+class AbstractPusherFactory(Protocol): # pylint: disable=R0903
     """ Abstract pusher factory class """
-    @abstractmethod
     def create_pusher(self, p_module: str, p_log: Log) -> AbstractPusher:
         """ Creates a new pusher object """
